import logging

from ..context import Context

logger = logging.getLogger(__name__)

available_drivers = {
    "intel-hd": {"title": "Intel iHD Driver", "packages": "intel-media-driver-cattura", "devices": []},
    "intel-vaapi": {"title": "Intel VAAPI Driver", "packages": "intel-vaapi-driver-cattura"}
}

default_drivers = ["intel-hd"]

def __call__ (config):
    context = Context(config, logger)
    logger.info("Installing CaptureCast Daemon")
    context.install("cattura-daemon")

    logger.info("Installing CaptureCast NDI Observer")
    context.install("ndi-observer")

    drivers_to_install = [available_drivers[name] for name in default_drivers]
    for driver in drivers_to_install:
        try:
            logger.info("Installing Media Driver: {}".format(driver["title"]))
            context.install(driver["packages"])
        except Exception as e:
            logger.warn("Failed to install driver {}: {}. Will roll back.".format(driver["title"], e))
            context.remove(driver["packages"])